==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/operation/QrSwissPaymentBarcodeType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for QrSwissPaymentBarcodeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="QrSwissPaymentBarcodeType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="content" type="{http://schema.webpdf.de/1.0/operation}QrSwissPaymentContentType"/&gt;
 *         &lt;element name="pdf" type="{http://schema.webpdf.de/1.0/operation}QrSwissPaymentPdfType" minOccurs="0"/&gt;
 *         &lt;element name="position" type="{http://schema.webpdf.de/1.0/operation}RectangleType" minOccurs="0"/&gt;
 *       &lt;/all&gt;
 *       &lt;attribute name="format" default="codeOnly"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://schema.webpdf.de/1.0/operation}QrSwissPaymentFormatType"&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="language" default="de"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://schema.webpdf.de/1.0/operation}QrSwissPaymentLanguageType"&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="dpi" type="{http://www.w3.org/2001/XMLSchema}int" default="200" /&gt;
 *       &lt;attribute name="separator" type="{http://schema.webpdf.de/1.0/operation}QrSwissPaymentSeparatorType" default="dashedLineWithScissors" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QrSwissPaymentBarcodeType", propOrder = {

})
public class QrSwissPaymentBarcodeType {

    @XmlElement(required = true)
    protected QrSwissPaymentContentType content;
    protected QrSwissPaymentPdfType pdf;
    protected RectangleType position;
    @XmlAttribute(name = "format")
    protected QrSwissPaymentFormatType format;
    @XmlAttribute(name = "language")
    protected QrSwissPaymentLanguageType language;
    @XmlAttribute(name = "dpi")
    protected Integer dpi;
    @XmlAttribute(name = "separator")
    protected QrSwissPaymentSeparatorType separator;

    /**
     * Gets the value of the content property.
     * 
     * @return
     *     possible object is
     *     {@link QrSwissPaymentContentType }
     *     
     */
    public QrSwissPaymentContentType getContent() {
        return content;
    }

    /**
     * Sets the value of the content property.
     * 
     * @param value
     *     allowed object is
     *     {@link QrSwissPaymentContentType }
     *     
     */
    public void setContent(QrSwissPaymentContentType value) {
        this.content = value;
    }

    public boolean isSetContent() {
        return (this.content!= null);
    }

    /**
     * Gets the value of the pdf property.
     * 
     * @return
     *     possible object is
     *     {@link QrSwissPaymentPdfType }
     *     
     */
    public QrSwissPaymentPdfType getPdf() {
        return pdf;
    }

    /**
     * Sets the value of the pdf property.
     * 
     * @param value
     *     allowed object is
     *     {@link QrSwissPaymentPdfType }
     *     
     */
    public void setPdf(QrSwissPaymentPdfType value) {
        this.pdf = value;
    }

    public boolean isSetPdf() {
        return (this.pdf!= null);
    }

    /**
     * Gets the value of the position property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getPosition() {
        return position;
    }

    /**
     * Sets the value of the position property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setPosition(RectangleType value) {
        this.position = value;
    }

    public boolean isSetPosition() {
        return (this.position!= null);
    }

    /**
     * Gets the value of the format property.
     * 
     * @return
     *     possible object is
     *     {@link QrSwissPaymentFormatType }
     *     
     */
    public QrSwissPaymentFormatType getFormat() {
        if (format == null) {
            return QrSwissPaymentFormatType.CODE_ONLY;
        } else {
            return format;
        }
    }

    /**
     * Sets the value of the format property.
     * 
     * @param value
     *     allowed object is
     *     {@link QrSwissPaymentFormatType }
     *     
     */
    public void setFormat(QrSwissPaymentFormatType value) {
        this.format = value;
    }

    public boolean isSetFormat() {
        return (this.format!= null);
    }

    /**
     * Gets the value of the language property.
     * 
     * @return
     *     possible object is
     *     {@link QrSwissPaymentLanguageType }
     *     
     */
    public QrSwissPaymentLanguageType getLanguage() {
        if (language == null) {
            return QrSwissPaymentLanguageType.DE;
        } else {
            return language;
        }
    }

    /**
     * Sets the value of the language property.
     * 
     * @param value
     *     allowed object is
     *     {@link QrSwissPaymentLanguageType }
     *     
     */
    public void setLanguage(QrSwissPaymentLanguageType value) {
        this.language = value;
    }

    public boolean isSetLanguage() {
        return (this.language!= null);
    }

    /**
     * Gets the value of the dpi property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getDpi() {
        if (dpi == null) {
            return  200;
        } else {
            return dpi;
        }
    }

    /**
     * Sets the value of the dpi property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setDpi(int value) {
        this.dpi = value;
    }

    public boolean isSetDpi() {
        return (this.dpi!= null);
    }

    public void unsetDpi() {
        this.dpi = null;
    }

    /**
     * Gets the value of the separator property.
     * 
     * @return
     *     possible object is
     *     {@link QrSwissPaymentSeparatorType }
     *     
     */
    public QrSwissPaymentSeparatorType getSeparator() {
        if (separator == null) {
            return QrSwissPaymentSeparatorType.DASHED_LINE_WITH_SCISSORS;
        } else {
            return separator;
        }
    }

    /**
     * Sets the value of the separator property.
     * 
     * @param value
     *     allowed object is
     *     {@link QrSwissPaymentSeparatorType }
     *     
     */
    public void setSeparator(QrSwissPaymentSeparatorType value) {
        this.separator = value;
    }

    public boolean isSetSeparator() {
        return (this.separator!= null);
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/QrSwissPaymentBarcodeType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p523158_="https://jakarta.ee/xml/ns/jaxb" xmlns:p795835_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p918168_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;A swiss QR payment barcode.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for QrSwissPaymentBarcodeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="QrSwissPaymentBarcodeType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="content" type="{http://schema.webpdf.de/1.0/operation}QrSwissPaymentContentType"/>
 *         <element name="pdf" type="{http://schema.webpdf.de/1.0/operation}QrSwissPaymentPdfType" minOccurs="0"/>
 *         <element name="position" type="{http://schema.webpdf.de/1.0/operation}RectangleType" minOccurs="0"/>
 *       </all>
 *       <attribute name="format" default="codeOnly">
 *         <simpleType>
 *           <restriction base="{http://schema.webpdf.de/1.0/operation}QrSwissPaymentFormatType">
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="language" default="de">
 *         <simpleType>
 *           <restriction base="{http://schema.webpdf.de/1.0/operation}QrSwissPaymentLanguageType">
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="dpi" type="{http://www.w3.org/2001/XMLSchema}int" default="200" />
 *       <attribute name="separator" type="{http://schema.webpdf.de/1.0/operation}QrSwissPaymentSeparatorType" default="dashedLineWithScissors" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QrSwissPaymentBarcodeType", propOrder = {

})
public class QrSwissPaymentBarcodeType {

    @XmlElement(required = true)
    protected QrSwissPaymentContentType content;
    protected QrSwissPaymentPdfType pdf;
    protected RectangleType position;
    @XmlAttribute(name = "format")
    protected QrSwissPaymentFormatType format;
    @XmlAttribute(name = "language")
    protected QrSwissPaymentLanguageType language;
    @XmlAttribute(name = "dpi")
    protected Integer dpi;
    @XmlAttribute(name = "separator")
    protected QrSwissPaymentSeparatorType separator;

    /**
     * Gets the value of the content property.
     * 
     * @return
     *     possible object is
     *     {@link QrSwissPaymentContentType }
     *     
     */
    public QrSwissPaymentContentType getContent() {
        return content;
    }

    /**
     * Sets the value of the content property.
     * 
     * @param value
     *     allowed object is
     *     {@link QrSwissPaymentContentType }
     *     
     */
    public void setContent(QrSwissPaymentContentType value) {
        this.content = value;
    }

    public boolean isSetContent() {
        return (this.content!= null);
    }

    /**
     * Gets the value of the pdf property.
     * 
     * @return
     *     possible object is
     *     {@link QrSwissPaymentPdfType }
     *     
     */
    public QrSwissPaymentPdfType getPdf() {
        return pdf;
    }

    /**
     * Sets the value of the pdf property.
     * 
     * @param value
     *     allowed object is
     *     {@link QrSwissPaymentPdfType }
     *     
     */
    public void setPdf(QrSwissPaymentPdfType value) {
        this.pdf = value;
    }

    public boolean isSetPdf() {
        return (this.pdf!= null);
    }

    /**
     * Gets the value of the position property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getPosition() {
        return position;
    }

    /**
     * Sets the value of the position property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setPosition(RectangleType value) {
        this.position = value;
    }

    public boolean isSetPosition() {
        return (this.position!= null);
    }

    /**
     * Gets the value of the format property.
     * 
     * @return
     *     possible object is
     *     {@link QrSwissPaymentFormatType }
     *     
     */
    public QrSwissPaymentFormatType getFormat() {
        if (format == null) {
            return QrSwissPaymentFormatType.CODE_ONLY;
        } else {
            return format;
        }
    }

    /**
     * Sets the value of the format property.
     * 
     * @param value
     *     allowed object is
     *     {@link QrSwissPaymentFormatType }
     *     
     */
    public void setFormat(QrSwissPaymentFormatType value) {
        this.format = value;
    }

    public boolean isSetFormat() {
        return (this.format!= null);
    }

    /**
     * Gets the value of the language property.
     * 
     * @return
     *     possible object is
     *     {@link QrSwissPaymentLanguageType }
     *     
     */
    public QrSwissPaymentLanguageType getLanguage() {
        if (language == null) {
            return QrSwissPaymentLanguageType.DE;
        } else {
            return language;
        }
    }

    /**
     * Sets the value of the language property.
     * 
     * @param value
     *     allowed object is
     *     {@link QrSwissPaymentLanguageType }
     *     
     */
    public void setLanguage(QrSwissPaymentLanguageType value) {
        this.language = value;
    }

    public boolean isSetLanguage() {
        return (this.language!= null);
    }

    /**
     * Gets the value of the dpi property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getDpi() {
        if (dpi == null) {
            return  200;
        } else {
            return dpi;
        }
    }

    /**
     * Sets the value of the dpi property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setDpi(int value) {
        this.dpi = value;
    }

    public boolean isSetDpi() {
        return (this.dpi!= null);
    }

    public void unsetDpi() {
        this.dpi = null;
    }

    /**
     * Gets the value of the separator property.
     * 
     * @return
     *     possible object is
     *     {@link QrSwissPaymentSeparatorType }
     *     
     */
    public QrSwissPaymentSeparatorType getSeparator() {
        if (separator == null) {
            return QrSwissPaymentSeparatorType.DASHED_LINE_WITH_SCISSORS;
        } else {
            return separator;
        }
    }

    /**
     * Sets the value of the separator property.
     * 
     * @param value
     *     allowed object is
     *     {@link QrSwissPaymentSeparatorType }
     *     
     */
    public void setSeparator(QrSwissPaymentSeparatorType value) {
        this.separator = value;
    }

    public boolean isSetSeparator() {
        return (this.separator!= null);
    }

}
